@@ -1,53 +1,46 @@
-package B::Hooks::EndOfScope;
-BEGIN {
-  $B::Hooks::EndOfScope::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $B::Hooks::EndOfScope::VERSION = '0.12';
-}
+package B::Hooks::EndOfScope; # git description: 0.18-2-gb54c9b1
 # ABSTRACT: Execute code after a scope finished compilation
+# KEYWORDS: code hooks execution scope
 
 use strict;
 use warnings;
 
+our $VERSION = '0.19';
+
 # note - a %^H tie() fallback will probably work on 5.6 as well,
 # if you need to go that low - sane patches passing *all* tests
 # will be gladly accepted
 use 5.008001;
 
 BEGIN {
-  require Module::Implementation;
-  my $impl = Module::Implementation::implementation_for('B::Hooks::EndOfScope') || do {
-    Module::Implementation::build_loader_sub(
-      implementations => [ 'XS', 'PP' ],
-      symbols => [ 'on_scope_end' ],
-    )->();
-    Module::Implementation::implementation_for('B::Hooks::EndOfScope');
-  };
-
-  *on_scope_end = $impl eq 'XS'
-    ? \&B::Hooks::EndOfScope::XS::on_scope_end
-    : \&B::Hooks::EndOfScope::PP::on_scope_end
-  ;
+  use Module::Implementation 0.05;
+  Module::Implementation::build_loader_sub(
+    implementations => [ 'XS', 'PP' ],
+    symbols => [ 'on_scope_end' ],
+  )->();
 }
 
-use Sub::Exporter::Progressive -setup => {
+use Sub::Exporter::Progressive 0.001006 -setup => {
   exports => [ 'on_scope_end' ],
   groups  => { default => ['on_scope_end'] },
 };
 
-
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 B::Hooks::EndOfScope - Execute code after a scope finished compilation
 
+=head1 VERSION
+
+version 0.19
+
 =head1 SYNOPSIS
 
     on_scope_end { ... };
@@ -95,6 +88,11 @@ L<Sub::Exporter>
 
 L<Variable::Magic>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=B-Hooks-EndOfScope>
+(or L<bug-B-Hooks-EndOfScope@rt.cpan.org|mailto:bug-B-Hooks-EndOfScope@rt.cpan.org>).
+
 =head1 AUTHORS
 
 =over 4
@@ -109,12 +107,35 @@ Peter Rabbitson <ribasushi@cpan.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTORS
 
-This software is copyright (c) 2012 by Florian Ragwitz.
+=for stopwords Karen Etheridge Simon Wilper Tatsuhiko Miyagawa Tomas Doran
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Simon Wilper <sxw@chronowerks.de>
+
+=item *
+
+Tatsuhiko Miyagawa <miyagawa@bulknews.net>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
